==> CGMyOrders-1.0.tar.gz: CGMyOrders/lang/en_US.php <==
<?php
#A
$lang['amtdue'] = 'Amt. Due';

#B

#C
$lang['created'] = 'Created';

#D
$lang['dflt_templates'] = 'Default Templates';

#E
$lang['error_emailnotspecified'] = 'Please specify an email address';

#F
$lang['friendlyname'] = 'Customer Order Viewer';

#G

#H
$lang['help'] = <<<EOT
<h3>What Does This Do?</h3>
<p>This module allows your e-commerce customers to view the invoices from the orders that they have created on your site in the past.  It reads the order information directly from the Orders module and uses an invoice template from the Orders module to generate invoices.</p>
<h3>Features:</h3>
<ul>
  <li>Support for anonymous users.
    <p>If you allow anonymous checkout, you can allow anonymous users to view their past orders merely by entering their email address.</p>
  </li>
  <li>Works with logged in Frontend Users
    <p>The default action will detect the currently logged in users user identifier, and query the database for the orders placed by that FEU user.</p>
  </li>
  <li>Allows limiting the number of views.
    <p>A module preference can be set to ensure that a user does not view an invoice more than N times.  This can be useful with digital downloads that generate time limited URLS from the invoice template.  Thereby your users cannot re-generate a time limited url to a download indefinately.</p>
  </li>
</ul>
<h3>How do I use it:</h3>
<p>Once the module is installed, you should visit the modules admin panel and adjust the settings to suit the needs on your site.</p>
<p>If you are not allowing anonymous checkout, then the simplest way to use this module is to place the <code>{CGMyOrders}</code> tag onto a page only accessible by logged in users.  This will immediately generate a list of the orders for that user.</p>
<p>If you are allowing anonymous checkout, you may want to call the module as follows: <node>{CGMyOrders action=&quot;userid&quot;}</code>.  This will provide a simple form that allows the user to enter their email address to find orders matching the email address.</p>
<h3>Future Development</h3>
<p>Future versions of this module may include:
  <ul>
    <li>Extra security measures for the userid action.</li>
    <li>Sorting, Filtering, and pagination options for the order list view.</li>
    <li>The ability to communicate with the site administrators regarding issues with a particular order or invoice.</li>
  </ul>
</p>
<h3>Support:</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy\'s
module homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License:</h3>
<p>Copyright &copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&lt;calguy1000@cmsmadesimple.org&gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
EOT;

#I
$lang['info_orderlist_template'] = 'This template provides a summary view of orders that match the criteria specified';
$lang['info_useridform_template'] = 'This template provides a form by which users can be identified against orders, so that a list can be provided';
$lang['invoice'] = 'Invoice';
$lang['items'] = 'Items';


#J

#K

#L

#M
$lang['moddescription'] = 'A module that allows custoemrs to view (and possibly interact with) invoices from past orders.';
$lang['modified'] = 'Modified';

#N

#O
$lang['orderlist_template'] = 'Order List Templates';

#P
$lang['param_action'] = 'Specify the action to execute.   Possible values are: default,userid,view_invoice.<br/>
The default action will provide an order list that matches the criteria specified. By default it will use the currently logged in FEU user id.<br/>
The userid action can be used when allowing anonymous checkout to provide a simple form to allow the user to enter their email address for order matching.<br/>
The view_order action can be used to generate a report for a single order.</p>';
$lang['param_email'] = 'Applicable only to the default action, this parameter allows specifying an email address to match orders against.  If this parameter is used, then the users FEU uid will not be used.  This parameter is usually passed from the userid action.';
$lang['param_invoicetemplate'] = 'Applicable only to the view_invoice action, this parameter allows specifying a non default invoice template (invoice templates are located in the Orders module) to use when displaying an invoice';
$lang['param_order'] = 'Applicable only to the view_invoice action, this parameter allows specifing an integer order number to view.  This parameter is usually passed from the default (order list) action.';
$lang['param_orderlisttemplate'] = 'Applicable only to the default action (though it can be passed through from the userid action).  This parameter allows specifying by name, a non default orderlist tempalte to use when displaying a list of orders.';
$lang['param_useridtemplate'] = 'Applicable only to the userid action, this parameter allows specifying the name of a non-default userid template.  If not specified, the current default userid template will be specified.';
$lang['postinstall'] = 'Module successfully installed.  Please visit the modules admin panel and adjust necessary settings';
$lang['postuninstall'] = 'CGMyOrderrs module and all associated ata has been removed';
$lang['prompt_enteremail'] = 'Enter the email address used in the billing stage of the checkout process';
$lang['prompt_max_invoice_views'] = 'Maximum number of times that an invoice can be viewed (enter 0 for unlimited)';
$lang['prompt_invoice_rpt_page'] = 'What page should be used for the invoice display';

#Q

#R
$lang['really_uninstall'] = 'Are you sure you really want to uninstall this module?  Doing so may break functionality on a running website.';

#S
$lang['settings'] = 'Settings';
$lang['status'] = 'Status';
$lang['submit'] = 'Submit';

#T
$lang['title_orderlist_template'] = 'Order List Template';
$lang['title_sysdflt_orderlist_template'] = 'System Default Order List Template';
$lang['title_sysdflt_useridform_template'] = 'System Default User Identification Form Template';
$lang['title_useridform_template'] = 'User Identification Form Template';
$lang['total'] = 'Total';

#U
$lang['userid_form_template'] = 'User Identification Form Templates';

#V
$lang['view_invoice'] = 'View This Invoice';

#W
$lang['weight'] = 'Weight';

#X

#Y

#Z
?>

==> CGMyOrders-1.1.tar.gz: CGMyOrders/lang/en_US.php <==
<?php
#A
$lang['amtdue'] = 'Amt. Due';

#B

#C
$lang['created'] = 'Created';

#D
$lang['dflt_templates'] = 'Default Templates';

#E
$lang['error_emailnotspecified'] = 'Please specify an email address';
$lang['error_noordersfound'] = 'No orders found';

#F
$lang['friendlyname'] = 'Customer Order Viewer';

#G

#H

#I
$lang['info_orderlist_template'] = 'This template provides a summary view of orders that match the criteria specified';
$lang['info_useridform_template'] = 'This template provides a form by which users can be identified against orders, so that a list can be provided';
$lang['invoice'] = 'Invoice';
$lang['items'] = 'Items';


#J

#K

#L

#M
$lang['moddescription'] = 'A module that allows custoemrs to view (and possibly interact with) invoices from past orders.';
$lang['modified'] = 'Modified';

#N

#O
$lang['orderlist_template'] = 'Order List Templates';

#P
$lang['param_action'] = 'Specify the action to execute.   Possible values are: default,userid,view_invoice.<br/>
The default action will provide an order list that matches the criteria specified. By default it will use the currently logged in FEU user id.<br/>
The userid action can be used when allowing anonymous checkout to provide a simple form to allow the user to enter their email address for order matching.<br/>
The view_order action can be used to generate a report for a single order.</p>';
$lang['param_email'] = 'Applicable only to the default action, this parameter allows specifying an email address to match orders against.  If this parameter is used, then the users FEU uid will not be used.  This parameter is usually passed from the userid action.';
$lang['param_invoicetemplate'] = 'Applicable only to the view_invoice action, this parameter allows specifying a non default invoice template (invoice templates are located in the Orders module) to use when displaying an invoice';
$lang['param_order'] = 'Applicable only to the view_invoice action, this parameter allows specifing an integer order number to view.  This parameter is usually passed from the default (order list) action.';
$lang['param_orderlisttemplate'] = 'Applicable only to the default action (though it can be passed through from the userid action).  This parameter allows specifying by name, a non default orderlist tempalte to use when displaying a list of orders.';
$lang['param_useridtemplate'] = 'Applicable only to the userid action, this parameter allows specifying the name of a non-default userid template.  If not specified, the current default userid template will be specified.';
$lang['postinstall'] = 'Module successfully installed.  Please visit the modules admin panel and adjust necessary settings';
$lang['postuninstall'] = 'CGMyOrderrs module and all associated ata has been removed';
$lang['prompt_enteremail'] = 'Enter the email address used in the billing stage of the checkout process';
$lang['prompt_max_invoice_views'] = 'Maximum number of times that an invoice can be viewed (enter 0 for unlimited)';
$lang['prompt_invoice_rpt_page'] = 'What page should be used for the invoice display';

#Q

#R
$lang['really_uninstall'] = 'Are you sure you really want to uninstall this module?  Doing so may break functionality on a running website.';

#S
$lang['settings'] = 'Settings';
$lang['status'] = 'Status';
$lang['submit'] = 'Submit';

#T
$lang['title_orderlist_template'] = 'Order List Template';
$lang['title_sysdflt_orderlist_template'] = 'System Default Order List Template';
$lang['title_sysdflt_useridform_template'] = 'System Default User Identification Form Template';
$lang['title_useridform_template'] = 'User Identification Form Template';
$lang['total'] = 'Total';

#U
$lang['userid_form_template'] = 'User Identification Form Templates';

#V
$lang['view_invoice'] = 'View This Invoice';

#W
$lang['weight'] = 'Weight';

#X

#Y

#Z
?>
